summaryrefslogtreecommitdiff
path: root/src/newgrf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/newgrf.cpp')
-rw-r--r--src/newgrf.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/newgrf.cpp b/src/newgrf.cpp
index aa4802226..097e68ae2 100644
--- a/src/newgrf.cpp
+++ b/src/newgrf.cpp
@@ -8389,7 +8389,8 @@ static void InitializeGRFSpecial()
| (1 << 0x1E) // variablerunningcosts
| (1 << 0x1F); // any switch is on
- _ttdpatch_flags[4] = (1 << 0x00); // larger persistent storage
+ _ttdpatch_flags[4] = (1 << 0x00) // larger persistent storage
+ | ((_settings_game.economy.inflation ? 1 : 0) << 0x01); // inflation is on
}
/** Reset and clear all NewGRF stations */